summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmquickcoloredit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmquickcoloredit.h')
-rw-r--r--kpovmodeler/pmquickcoloredit.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kpovmodeler/pmquickcoloredit.h b/kpovmodeler/pmquickcoloredit.h
index 7f6d16e9..456b9660 100644
--- a/kpovmodeler/pmquickcoloredit.h
+++ b/kpovmodeler/pmquickcoloredit.h
@@ -17,8 +17,8 @@
**************************************************************************/
-#ifndef PMQUICKCOLOREDIT_H
-#define PMQUICKCOLOREDIT_H
+#ifndef PMTQUICKCOLOREDIT_H
+#define PMTQUICKCOLOREDIT_H
#ifdef HAVE_CONFIG_H
#include <config.h>
@@ -37,12 +37,13 @@ class PMColorEdit;
class PMQuickColorEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMQuickColorEdit with parent and name
*/
- PMQuickColorEdit( TQWidget* parent, const char* name = 0 );
+ PMQuickColorEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -37,12 +37,13 @@ class PMColorEdit;
public:
/**
- * Creates a PMQuickColorEdit with parent and name
+ * Creates a PMQuickColorEdit with tqparent and name
*/